@@ -2,10 +2,11 @@ from __future__ import annotations
 
 from base64 import b64decode
 from typing import Optional
+from copy import deepcopy
 
 import netunicorn.base.environment_definitions
 
-from .minions import Minion
+from .nodes import Node
 from .pipeline import Pipeline
 from .task import TaskDispatcher
 from .utils import SerializedPipelineType
@@ -20,17 +21,20 @@ except ImportError:
 
 
 class Deployment:
-    def __init__(self, minion: Minion, pipeline: Pipeline):
-        self.minion = minion
+    def __init__(
+        self, node: Node, pipeline: Pipeline, keep_alive_timeout_minutes: int = 10
+    ):
+        self.node = node
         self.prepared = False
         self.executor_id = ""
         self.error: Optional[Exception] = None
         self.pipeline: SerializedPipelineType = b""
-        self.environment_definition = pipeline.environment_definition
+        self.environment_definition = deepcopy(pipeline.environment_definition)
+        self.keep_alive_timeout_minutes = keep_alive_timeout_minutes
 
         for i, element in enumerate(pipeline.tasks):
             pipeline.tasks[i] = [
-                x.dispatch(minion) if isinstance(x, TaskDispatcher) else x
+                x.dispatch(node) if isinstance(x, TaskDispatcher) else x
                 for x in element
             ]
             for x in pipeline.tasks[i]:
@@ -39,18 +43,19 @@ class Deployment:
         self.pipeline = cloudpickle.dumps(pipeline)
 
     def __str__(self):
-        return f"Deployment: Minion={self.minion.name}, executor_id={self.executor_id}, prepared={self.prepared}"
+        return f"Deployment: Node={self.node.name}, executor_id={self.executor_id}, prepared={self.prepared}"
 
     def __repr__(self):
         return self.__str__()
 
     def __json__(self):
         return {
-            "minion": self.minion.__json__(),
+            "node": self.node.__json__(),
             "prepared": self.prepared,
             "executor_id": self.executor_id,
             "error": str(self.error) if self.error else None,
             "pipeline": self.pipeline,
+            "keep_alive_timeout_minutes": self.keep_alive_timeout_minutes,
             "environment_definition": self.environment_definition.__json__(),
             "environment_definition_type": self.environment_definition.__class__.__name__,
         }
@@ -59,11 +64,12 @@ class Deployment:
     def from_json(cls, data: dict):
         instance = cls.__new__(cls)
 
-        instance.minion = Minion.from_json(data["minion"])
+        instance.node = Node.from_json(data["node"])
         instance.prepared = data["prepared"]
         instance.executor_id = data["executor_id"]
         instance.error = Exception(data["error"]) if data["error"] else None
         instance.pipeline = b64decode(data["pipeline"])
+        instance.keep_alive_timeout_minutes = data["keep_alive_timeout_minutes"]
         instance.environment_definition = getattr(
             netunicorn.base.environment_definitions, data["environment_definition_type"]
         ).from_json(data["environment_definition"])
