@@ -4,13 +4,33 @@ import sys
 
 __logging.basicConfig()
 
-DATABASE_ENDPOINT = __os.environ.get("NETUNICORN_DATABASE_ENDPOINT", "127.0.0.1")
-DATABASE_USER = __os.environ.get("NETUNICORN_DATABASE_USER", "unicorn")
-DATABASE_PASSWORD = __os.environ.get("NETUNICORN_DATABASE_PASSWORD", "unicorn")
-DATABASE_DB = __os.environ.get("NETUNICORN_DATABASE_DB", "unicorndb")
+DATABASE_ENDPOINT = __os.environ.get("NETUNICORN_DATABASE_ENDPOINT", None)
+DATABASE_ENDPOINT_DEFAULT = False
+if DATABASE_ENDPOINT is None:
+    DATABASE_ENDPOINT_DEFAULT = True
+    DATABASE_ENDPOINT = "127.0.0.1"
+
+DATABASE_USER = __os.environ.get("NETUNICORN_DATABASE_USER", None)
+DATABASE_USER_DEFAULT = False
+if DATABASE_USER is None:
+    DATABASE_USER_DEFAULT = True
+    DATABASE_USER = "unicorn"
+
+DATABASE_PASSWORD = __os.environ.get("NETUNICORN_DATABASE_PASSWORD", None)
+DATABASE_PASSWORD_DEFAULT = False
+if DATABASE_PASSWORD is None:
+    DATABASE_PASSWORD_DEFAULT = True
+    DATABASE_PASSWORD = "unicorn"
+
+DATABASE_DB = __os.environ.get("NETUNICORN_DATABASE_DB", None)
+DATABASE_DB_DEFAULT = False
+if DATABASE_DB is None:
+    DATABASE_DB_DEFAULT = True
+    DATABASE_DB = "unicorndb"
+
 __logging.info(f"Connecting to {DATABASE_ENDPOINT}/{DATABASE_DB} as {DATABASE_USER}")
 
-__logging_levels = {
+LOGGING_LEVELS = {
     "DEBUG": __logging.DEBUG,
     "INFO": __logging.INFO,
     "WARNING": __logging.WARNING,
@@ -19,7 +39,7 @@ __logging_levels = {
 }
 
 __logger_level = __os.environ.get("NETUNICORN_LOG_LEVEL", "INFO").upper()
-__logger_level = __logging_levels.get(__logger_level, __logging.INFO)
+__logger_level = LOGGING_LEVELS.get(__logger_level, __logging.INFO)
 
 
 def get_logger(name: str, level: int = __logger_level) -> __logging.Logger:
